@@ -12,10 +12,23 @@ angular.module("bulkfileupload/fileinfo.tpl.html", []).run(["$templateCache", fu
     "            'cradmin-legacy-bulkfileupload-progress-item-finished': fileInfo.finished,\n" +
     "            'cradmin-legacy-bulkfileupload-progress-item-error cradmin-legacy-bulkfileupload-errorparagraph': fileInfo.hasErrors\n" +
     "        }\">\n" +
+    "    <span class=\"cradmin-legacy-bulkfileupload-iteminfo\">\n" +
+    "        <span class=\"cradmin-legacy-progressbar\">\n" +
+    "            <span class=\"cradmin-legacy-progressbar-progress\" ng-style=\"{'width': fileInfo.percent+'%'}\">&nbsp;</span>\n" +
+    "            <span class=\"cradmin-legacy-progresspercent\" role='progressbar' aria-valuenow=\"{{ fileInfo.percent }}\" aria-valuemin=\"0\" aria-valuemax=\"100\"\n" +
+    "                    aria-labelledby=\"id_uploadfilename_{{ fileInfo.temporaryfileid }}\">\n" +
+    "                <span class=\"cradmin-legacy-progresspercent-number\" aria-hidden=\"true\">{{ fileInfo.percent }}</span>%\n" +
+    "            </span>\n" +
+    "        </span>\n" +
+    "        <span id=\"id_uploadfilename_{{ fileInfo.temporaryfileid }}\" style=\"display: none;\">{{fileInfo.name}}: {{fileInfo.i18nStrings.upload_status}} {{ fileInfo.percent }}%</span>\n" +
+    "        <span class=\"cradmin-legacy-filename\" aria-hidden=\"true\">{{fileInfo.name}}</span>\n" +
+    "    </span>\n" +
+    "\n" +
     "    <button cradmin-legacy-bulkfileupload-remove-file-button=\"fileInfo\"\n" +
     "            ng-if=\"fileInfo.finished\"\n" +
     "            type=\"button\"\n" +
-    "            class=\"btn btn-link cradmin-legacy-bulkfileupload-remove-file-button\">\n" +
+    "            class=\"btn btn-link cradmin-legacy-bulkfileupload-remove-file-button\"\n" +
+    "            aria-describedby=\"id_uploadfilename_{{ fileInfo.temporaryfileid }}\">\n" +
     "        <span ng-if=\"!fileInfo.isRemoving &amp;&amp; !fileInfo.autosubmit\"\n" +
     "              class=\"cradmin-legacy-bulkfileupload-remove-file-button-isnotremoving\">\n" +
     "            <span class=\"fa fa-times\"></span>\n" +
@@ -27,14 +40,6 @@ angular.module("bulkfileupload/fileinfo.tpl.html", []).run(["$templateCache", fu
     "            <span class=\"sr-only\">{{fileInfo.i18nStrings.removing_file_message}}</span>\n" +
     "        </span>\n" +
     "    </button>\n" +
-    "\n" +
-    "    <span class=\"cradmin-legacy-progressbar\">\n" +
-    "        <span class=\"cradmin-legacy-progressbar-progress\" ng-style=\"{'width': fileInfo.percent+'%'}\">&nbsp;</span>\n" +
-    "        <span class=\"cradmin-legacy-progresspercent\">\n" +
-    "            <span class=\"cradmin-legacy-progresspercent-number\">{{ fileInfo.percent }}</span>%\n" +
-    "        </span>\n" +
-    "    </span>\n" +
-    "    <span class=\"cradmin-legacy-filename\">{{fileInfo.name}}</span>\n" +
     "</p>\n" +
     "");
 }]);
@@ -42,7 +47,7 @@ angular.module("bulkfileupload/fileinfo.tpl.html", []).run(["$templateCache", fu
 angular.module("bulkfileupload/progress.tpl.html", []).run(["$templateCache", function($templateCache) {
   $templateCache.put("bulkfileupload/progress.tpl.html",
     "<div class=\"cradmin-legacy-bulkfileupload-progress\">\n" +
-    "    <div ng-repeat=\"fileInfo in fileInfoArray\">\n" +
+    "    <div ng-repeat=\"fileInfo in fileInfoArray\" aria-live='assertive'>\n" +
     "        <div cradmin-legacy-bulk-file-info=\"fileInfo\"\n" +
     "             class=\"cradmin-legacy-bulkfileupload-progress-file\"></div>\n" +
     "    </div>\n" +
@@ -55,20 +60,23 @@ angular.module("bulkfileupload/rejectedfiles.tpl.html", []).run(["$templateCache
     "<div class=\"cradmin-legacy-bulkfileupload-rejectedfiles\">\n" +
     "    <p ng-repeat=\"fileInfo in rejectedFiles\"\n" +
     "            class=\"cradmin-legacy-bulkfileupload-rejectedfile cradmin-legacy-bulkfileupload-errorparagraph\">\n" +
+    "\n" +
+    "        <span class=\"cradmin-legacy-bulkfileupload-iteminfo\">\n" +
+    "            <span class=\"cradmin-legacy-bulkfileupload-rejectedfile-filename\">{{ fileInfo.name }}:</span>\n" +
+    "            <span ng-repeat=\"(errorfield,errors) in fileInfo.errors\">\n" +
+    "                <span ng-repeat=\"error in errors\"\n" +
+    "                    class=\"cradmin-legacy-bulkfileupload-error\">\n" +
+    "                    {{ error.message }}\n" +
+    "                </span>\n" +
+    "            </span>\n" +
+    "        </span>\n" +
+    "\n" +
     "        <button ng-click=\"closeMessage(fileInfo)\"\n" +
     "                type=\"button\"\n" +
     "                class=\"btn btn-link cradmin-legacy-bulkfileupload-error-closebutton\">\n" +
     "            <span class=\"fa fa-times\"></span>\n" +
     "            <span class=\"sr-only\">{{fileInfo.i18nStrings.close_errormessage_label}}</span>\n" +
     "        </button>\n" +
-    "\n" +
-    "        <span class=\"cradmin-legacy-bulkfileupload-rejectedfile-filename\">{{ fileInfo.name }}:</span>\n" +
-    "        <span ng-repeat=\"(errorfield,errors) in fileInfo.errors\">\n" +
-    "            <span ng-repeat=\"error in errors\"\n" +
-    "                  class=\"cradmin-legacy-bulkfileupload-error\">\n" +
-    "                {{ error.message }}\n" +
-    "            </span>\n" +
-    "        </span>\n" +
     "    </p>\n" +
     "</div>\n" +
     "");
